function [data,x] = create_piecewise_cst_1D(N,p,sig,xmax,xmin)
% Create a piecewise constant signal
%
% data = create_piecewise_cst_1D(N,p,snr_value,xmax,xmin)
% N      : sample size
% sigma  : standard deviation (default=0.1)
% xmax   : maximum value of true signal 'x' (default=1)
% xmin   : minimum value of true signal 'x' (default=0)
% p      : change-point probability (default=0.01)
%
% ex1 several changes and high snr
% >>  data = create_piecewise_cst_1D(1000,0.05,0.1);plot(data);
%
% ex2 few changes and low snr
% >> data = create_piecewise_cst_1D(1000,0.005,0.07);plot(data);
%
% Implementation N. PUSTELNIK, ENS Lyon
% June 2019
% Modified by B. PASCAL, ENS LYON
% March 2020



if ~exist('p') %#ok<EXIST>
    p = 0.01;
end
if ~exist('sig') %#ok<EXIST>
    sig = 0.1;
end
if ~exist('xmax') %#ok<EXIST>
    xmax = 1;
end
if ~exist('xmin') %#ok<EXIST>
    xmin = 0;
end

n           = sig*randn(1,N);
K           = p*N;
t           = rand(1,round(2*K))*2/p;
T           = cumsum(t);
T           = round(T(T<=1.5*N));
mu          = (xmax-xmin)*rand(size(T))+xmin;
x(1:T(1))   = mu(1);
for xx=2:length(T)
    x(T(xx-1)+1:T(xx)) = mu(xx);
end
x           = double(x(1:N));
data        = x + n;


